@@ -4,7 +4,7 @@
 lswifi.core
 ~~~~~~~~~~~
 
-core code to manage clients (interfaces), their data, and writing out results.
+code to manage clients (interfaces), their data, and writing out results.
 """
 
 # python imports
@@ -23,9 +23,11 @@ from .__version__ import __title__
 from .client import Client, get_interface_info
 from .constants import APNAMEJSONFILE
 from .elements import WirelessNetworkBss
-from .helpers import (OUT_TUPLE, SubHeader, format_bytes_as_hex,
+from .helpers import (Base64Encoder, format_bytes_as_hex,
                       generate_pretty_separator, get_attr_max_len,
-                      is_five_band, is_two_four_band, strip_mac_address_format)
+                      is_five_band, is_six_band, is_two_four_band,
+                      strip_mac_address_format)
+from .schemas.out import *
 
 
 def list_interfaces(interfaces) -> None:
@@ -73,6 +75,14 @@ async def scan(args, **kwargs):
             watch_events(args, interfaces)
             sys.exit(0)
 
+        if args.append:
+            appendEthers(args.append)
+            sys.exit(0)
+
+        if args.display_ethers:
+            displayEthers()
+            sys.exit(0)
+
         for interface in interfaces:
             if (
                 args.get_interface_info
@@ -111,7 +121,27 @@ async def scan(args, **kwargs):
             pass
 
 
-def appendEthers(data) -> dict:
+def displayEthers():
+    log = logging.getLogger(__name__)
+    appdata_path = os.path.join(os.getenv("LOCALAPPDATA"), __title__)
+    is_path = os.path.isdir(appdata_path)
+    if not is_path:
+        log.info("nothing here")
+
+    file = os.path.join(appdata_path, "ethers")
+
+    try:
+        if os.path.isfile(file):
+            content = ""
+            with open(file, "r") as file_reader:
+                content = file_reader.readlines()
+            content = [x.strip() for x in content]
+            print("\n".join(content))
+    except:
+        pass
+
+
+def appendEthers(data):
     log = logging.getLogger(__name__)
     appdata_path = os.path.join(os.getenv("LOCALAPPDATA"), __title__)
     is_path = os.path.isdir(appdata_path)
@@ -250,9 +280,6 @@ def parse_bss_list_and_print(wireless_network_bss_list, args, **kwargs):
                 else:
                     stored_ack = value
 
-    if args.append:
-        ethers = appendEthers(args.append)
-        sys.exit(0)
     if args.ethers:
         ethers = loadEthers()
 
@@ -351,18 +378,15 @@ def parse_bss_list_and_print(wireless_network_bss_list, args, **kwargs):
             if args.ies:
                 print(bss)
             if args.bytes:
-                # print(f"bss bytes:\n{bss.bssbytes.send()}\n")
-                print(f"type(bss.bssbytes.send(): {type(bss.bssbytes.send())}")
-                print(f"{bss.bssbytes.send()}")
+                print("bss.bssbytes.send():")
+                print(f"{bss.bssbytes.send()}\n")
+                print("base64 encoded (bss.bssbytes.send()):")
+                print(f"{json.dumps(bss.bssbytes.send(), cls=Base64Encoder)}\n")
                 print(
-                    f"unicode_escape: \n {(bss.bssbytes.send()).decode(encoding='unicode_escape')}\n"
+                    f"decoded as ISO-8859-1: \n {(bss.bssbytes.send()).decode(encoding='ISO-8859-1')}\n"
                 )
-                print(f"bss bytes:\n{format_bytes_as_hex(bss.bssbytes.send())}\n")
-                # print(f"bss bytes:\n{type(bss.bssbytes.send())}\n")
-                # print(f"ies bytes:\n{bss.iesbytes}\n")
-                print(f"ies bytes:\n{format_bytes_as_hex(bss.iesbytes)}\n")
-                # print(f"ies bytes:\n{type(bss.iesbytes)}\n")
-
+                print(f"bss octets:\n{format_bytes_as_hex(bss.bssbytes.send())}\n")
+                print(f"ies octets:\n{format_bytes_as_hex(bss.iesbytes)}\n")
             break
 
         # handle weakest rssi value we want to see displayed to the screen
@@ -379,19 +403,37 @@ def parse_bss_list_and_print(wireless_network_bss_list, args, **kwargs):
             continue
 
         # handle band filters
-        if args.a and args.g:
+        if args.a and args.g and args.six:
             pass
         else:
-            if args.g:
+            if args.a and args.g and not args.six:
                 if is_two_four_band(int(bss.channel_frequency.value)):
                     pass
-                else:
-                    continue
-            if args.a:
                 if is_five_band(int(bss.channel_frequency.value)):
                     pass
-                else:
+                if is_six_band(int(bss.channel_frequency.value)):
                     continue
+            if args.a and args.six and not args.g:
+                if is_two_four_band(int(bss.channel_frequency.value)):
+                    continue
+                if is_five_band(int(bss.channel_frequency.value)):
+                    pass
+                if is_six_band(int(bss.channel_frequency.value)):
+                    pass
+            if args.g and args.six and not args.six:
+                if is_two_four_band(int(bss.channel_frequency.value)):
+                    pass
+                if is_five_band(int(bss.channel_frequency.value)):
+                    continue
+                if is_six_band(int(bss.channel_frequency.value)):
+                    pass
+            if args.six and not args.a and not args.g:
+                if is_two_four_band(int(bss.channel_frequency.value)):
+                    continue
+                if is_five_band(int(bss.channel_frequency.value)):
+                    continue
+                if is_six_band(int(bss.channel_frequency.value)):
+                    pass
 
         # handle width filter
         valid_channels = ["20", "40", "80", "160"]
@@ -532,7 +574,7 @@ def parse_bss_list_and_print(wireless_network_bss_list, args, **kwargs):
 
     if args.uptime:  # sort by uptime
         out_results = sorted(
-            out_results, key=lambda x: int(x[8].value.split("d")[0]), reverse=False
+            out_results, key=lambda x: int(x[9].value.split("d")[0]), reverse=False
         )
     elif args.apnames or args.ethers:  # sort by RSSI
         out_results = sorted(out_results, key=lambda x: x[3].value, reverse=False)
